ColorDistanceSensor
===================

|location_link|

.. |location_link| raw:: html

   <a href="https://www.lego.com/en-gb/product/color-distance-sensor-88007" target="_blank">LEGO Color and Distance Sensor 88007</a>

|location_link2|

.. |location_link2| raw:: html

   <a href="https://www.bricklink.com/v2/catalog/catalogitem.page?P=bb0891c01#T=C&C=1" target="_blank">BrickLink listing</a>


The LEGO® Color and Distance Sensor can sort between six different colors and objects within 5 to 10 cm range

NOTE: Support for this device is experimental and not all features are available yet. 

.. autoclass:: buildhat.ColorDistanceSensor
   :members:
   :inherited-members:

Example
-------

.. literalinclude:: colordistance.py

